import React from 'react';
import PropTypes from 'prop-types';
import { isDarkMode } from '@cloudflare/style-const';
import {
  createComponent,
  createStyledComponent
} from '@cloudflare/style-container';

const styles = ({ theme, type = 'default' }) => {
  const darkMode = isDarkMode();
  return {
    m: 3,
    p: 3,
    border: '1px solid transparent',
    borderRadius: theme.radii[1],
    color: darkMode ? theme.colors.gray[1] : theme.colors.white,
    backgroundColor:
      type === 'info' ? (darkMode ? 'blue.9' : 'blue.4') : 'gray.1',
    borderColor: type === 'info' ? (darkMode ? 'blue.3' : 'blue.4') : 'gray.1'
  };
};

const Content = createComponent(
  () => ({
    marginTop: 0
  }),
  'p'
);

class Callout extends React.Component {
  render() {
    return (
      <div className={this.props.className}>
        <h3>{this.props.title}</h3>
        <Content>{this.props.content}</Content>
      </div>
    );
  }
}

Callout.propTypes = {
  className: PropTypes.string,
  type: PropTypes.oneOf(['default', 'info']),
  title: PropTypes.string,
  content: PropTypes.node.isRequired
};
Callout.displayName = 'Callout';
export default createStyledComponent(styles, Callout);
